==> jc-1.4.0.tar.gz: gnu/java/locale/LocaleInformation__5fes__5fPA.h <==
// public class gnu.java.locale.LocaleInformation_es_PA

// class file dependencies
// @dep_class 1baccae1dd8bc397 gnu_java_locale_LocaleInformation__5fes__5fPA
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fes__5fPA_H_
#define _JC_gnu_java_locale_LocaleInformation__5fes__5fPA_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$refs	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$object	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vmethods	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtable	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtype	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$fields_struct {
	_jc_object_array	*contents;
};
extern _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$fields_struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$object *);

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$object *);
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vmethods	gnu_java_locale_LocaleInformation__5fes__5fPA;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$refs {
    _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_refs	gnu_java_locale_LocaleInformation__5fes__5fPA;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_nonrefs	gnu_java_locale_LocaleInformation__5fes__5fPA;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$object {
	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtype _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fes__5fPA, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fes__5fPA_H_ */

==> jc-1.4.5.tar.gz: gnu/java/locale/LocaleInformation__5fes__5fPA.h <==
// public class gnu.java.locale.LocaleInformation_es_PA

// class file dependencies
// @dep_class 1baccae1dd8bc397 gnu_java_locale_LocaleInformation__5fes__5fPA
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fes__5fPA_H_
#define _JC_gnu_java_locale_LocaleInformation__5fes__5fPA_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$refs	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$object	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vmethods	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtable	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtype	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$fields_struct {
	_jc_object_array	*contents;
};
extern _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$fields_struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vmethods	gnu_java_locale_LocaleInformation__5fes__5fPA;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$refs {
    _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_refs	gnu_java_locale_LocaleInformation__5fes__5fPA;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$sub_nonrefs	gnu_java_locale_LocaleInformation__5fes__5fPA;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$object {
	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fPA$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$vtype _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fes__5fPA, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fes__5fPA$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fes__5fPA_H_ */
